<?php

/**
 * @file
 * Test file for Snapengage module.
 */

namespace Drupal\snapengage\Tests;

use Drupal\simpletest\WebTestBase;

/**
 * Test basic functionality of Snapengage module.
 */
class SnapengageBasicTest extends WebTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = array('snapengage');

  /**
   * Implements getInfo().
   */
  public static function getInfo() {
    return array(
      'name' => t('Snapengage basic tests'),
      'description' => t('Test basic functionality of Snapengage module.'),
      'group' => 'SnapEngage',
    );
  }

  /**
   * Implements DrupalWebTestCase::setup().
   */
  public function setUp() {
    parent::setUp();

    $permissions = array(
      'access administration pages',
      'administer snapengage',
    );

    // User to set up snapengage.
    $this->admin_user = $this->drupalCreateUser($permissions);
    $this->drupalLogin($this->admin_user);
  }

  /**
   * Check presence of the settings page.
   */
  public function testSnapengageConfiguration() {
    // Check for setting page's presence.
    $this->drupalGet('admin/config/system/snapengage');
    $this->assertRaw(t('Widget ID'), '[testSnapengageConfiguration]: Settings page displayed.');
  }

  /**
   * Check that the SnapEngage widget code is visible.
   */
  public function testSnapengagePageVisibility() {
    $config = config('snapengage.settings');

    $widget_id = 'abcdefgh-1234-ijkl-5678-mnopqrstuvwx';
    $config->set('widget_id', $widget_id);

    // Show widget on "every page except the listed pages".
    $config->set('visibility', 0);
    // Disable widget one "admin*" pages only.
    $config->set('pages', "admin\nadmin/*");
    // Enable widget only for authenticated users only.
    $config->set('roles', array(DRUPAL_AUTHENTICATED_RID => DRUPAL_AUTHENTICATED_RID));

    $config->save();

    // Check widget code visibility.
    $this->drupalGet('');
    $this->assertRaw($widget_id, '[testSnapengagePageVisibility]: Display widget for authenticated users.');

    // Test whether widget code is not included on pages to omit.
    $this->drupalGet('admin');
    $this->assertNoRaw($widget_id, '[testSnapengagePageVisibility]: Don\'t display widget on admin page.');
    $this->drupalGet('admin/config/system/snapengage');
    // Checking for widget code URI here, because the form displays
    // the $widget_id.
    $this->assertNoRaw('snapabug.appspot.com/snapabug.js', '[testSnapengagePageVisibility]: Don\'t display widget on admin subpage.');

    // Test whether widget code display is properly flipped.
    $config->set('visibility', 1);
    $config->save();

    $this->drupalGet('admin');
    $this->assertRaw($widget_id, '[testSnapengagePageVisibility]: Display widget code on admin page.');
    $this->drupalGet('admin/config/system/snapengage');
    // Checking for widget code URI here, because the form displays
    // the $widget_id.
    $this->assertRaw('snapabug.appspot.com/snapabug.js', '[testSnapengagePageVisibility]: Display widget code on admin subpage.');
    $this->drupalGet('');
    $this->assertNoRaw($widget_id, '[testSnapengagePageVisibility]: Don\'t display widget on front page.');

    // Test whether widget code is not display for anonymous.
    $this->drupalLogout();
    $this->drupalGet('');
    $this->assertNoRaw($widget_id, '[testSnapengagePageVisibility]: Don\'t display widget for anonymous users.');
  }

  /**
   * Check whether it is possible to inject code via the widget ID.
   */
  public function testSnapengageXssTest() {
    $config = config('snapengage.settings');

    $widget_id = "abcdefgh-1234-ijkl-5678-mnopqrstuvwx');alert('XSS');//";
    $config->set('widget_id', $widget_id);

    $config->save();

    // Check widget code visibility.
    $this->drupalGet('');
    $this->assertNoRaw("alert('XSS')", '[testSnapengageXss]: Widget ID is XSS protected.');
  }
}
