<?php

/**
 * @file
 * Test file for Snapengage module.
 */

namespace Drupal\snapengage\Tests;

use Drupal\simpletest\WebTestBase;

/**
 * Test roles functionality of SnapEngage module.
 */
class SnapengageRolesTest extends WebTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = array('snapengage');

  /**
   * Implements getInfo().
   */
  public static function getInfo() {
    return array(
      'name' => t('SnapEngage role tests'),
      'description' => t('Test roles functionality of SnapEngage module.'),
      'group' => 'SnapEngage',
    );
  }

  /**
   * Implements DrupalWebTestCase::setup().
   */
  public function setUp() {
    parent::setUp();

    $permissions = array(
      'access administration pages',
      'administer snapengage',
    );

    // User to set up snapengage.
    $this->admin_user = $this->drupalCreateUser($permissions);
  }

  /**
   * Test how the widget displays for different roles.
   */
  public function testSnapengageRolesWidget() {
    $config = config('snapengage.settings');

    $widget_id = 'abcdefgh-1234-ijkl-5678-mnopqrstuvwx';
    $config->set('widget_id', $widget_id);

    // Test if the default settings are working as expected.
    // Enable widget for all users.
    $config->set('roles', array());

    $config->save();

    // Check widget code visibility.
    $this->drupalGet('');
    $this->assertRaw($widget_id, '[testSnapengageRoleVisibility]: Display widget for anonymous users on frontpage with default settings.');
    $this->drupalGet('admin');
    $this->assertRaw($widget_id, '[testSnapengageRoleVisibility]: Display widget for anonymous users in admin section with default settings.');

    $this->drupalLogin($this->admin_user);

    $this->drupalGet('');
    $this->assertRaw($widget_id, '[testSnapengageRoleVisibility]: Display widget for authenticated users on frontpage with default settings.');
    $this->drupalGet('admin');
    $this->assertRaw($widget_id, '[testSnapengageRoleVisibility]: Display widget for authenticated users in admin section with default settings.');

    // Test if the non-default settings are working as expected.
    // Enable widget only for authenticated users.
    $config->set('roles', array(DRUPAL_AUTHENTICATED_RID => DRUPAL_AUTHENTICATED_RID));
    $config->save();

    $this->drupalGet('');
    $this->assertRaw($widget_id, '[testSnapengageRoleVisibility]: Display widget for authenticated users on frontpage.');

    $this->drupalLogout();
    $this->drupalGet('');
    $this->assertNoRaw($widget_id, '[testSnapengageRoleVisibility]: Don\'t display widget for anonymous users on frontpage.');
  }
}
