<?php

/**
 * @file
 * Administrative page callbacks for the snapengage module.
 */

/**
 * Form constructor for the admin settings form.
 *
 * @see snapengage_menu()
 * @ingroup forms
 */
function snapengage_admin_settings_form($form_state) {
  $config = config('snapengage.settings');
  $form = array();

  $form['account'] = array(
    '#type' => 'fieldset',
    '#title' => t('General settings'),
    '#collapsible' => FALSE,
  );

  $form['account']['widget_id'] = array(
    '#type' => 'textfield',
    '#title' => t('Widget ID'),
    '#default_value' => $config->get('widget_id'),
    '#required' => TRUE,
    '#description' => t('Your widget ID. It will look somewhat like this: "abcdefgh-1234-ijkl-5678-mnopqrstuvwx". You can find it at <a href="!url">!url</a>.', array('!url' => 'https://secure.snapengage.com/widget')),
  );

  // Render the role overview.
  $form['role_vis_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Role specific visibility settings'),
    '#collapsible' => TRUE,
  );

  $roles = user_roles();
  $role_options = array();
  foreach ($roles as $rid => $name) {
    $role_options[$rid] = $name;
  }
  $form['role_vis_settings']['roles'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Role specific visibility'),
    '#default_value' => $config->get('roles'),
    '#options' => $role_options,
    '#description' => t('Show widget only for the selected role(s). If you select none of the roles, then all roles will see the widget. If a user has any of the roles checked, the widget will be visible to the user.'),
  );

  // Page specific visibility configurations.
  $form['page_vis_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Page specific visibility settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $access = user_access('use PHP for SnapEngage visibility');
  $visibility = $config->get('visibility');
  $pages = $config->get('pages');

  if ($visibility == 2 && !$access) {
    $form['page_vis_settings'] = array();
    $form['page_vis_settings']['visibility'] = array('#type' => 'value', '#value' => 2);
    $form['page_vis_settings']['pages'] = array('#type' => 'value', '#value' => $pages);
  }
  else {
    $options = array(t('Add to every page except the listed pages.'), t('Add to the listed pages only.'));
    $description = t("Enter one page per line as Drupal paths. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.",
                   array(
                     '%blog' => 'blog',
                     '%blog-wildcard' => 'blog/*',
                     '%front' => '<front>',
                   ));

    if (module_exists('php') && $access) {
      $options[] = t('Add if the following PHP code returns <code>TRUE</code> (PHP-mode, experts only).');
      $description .= ' ' . t('If you choose the PHP-mode, enter PHP code between %php. Note that executing incorrect PHP-code can break your Drupal site.', array('%php' => '<?php ?>'));
    }
    $form['page_vis_settings']['visibility'] = array(
      '#type' => 'radios',
      '#title' => t('Add widget to specific pages'),
      '#options' => $options,
      '#default_value' => $visibility,
    );
    $form['page_vis_settings']['pages'] = array(
      '#type' => 'textarea',
      '#title' => t('Pages'),
      '#default_value' => $pages,
      '#description' => $description,
      '#wysiwyg' => FALSE,
    );
    $form['#submit'][] = 'snapengage_admin_settings_form_submit';
  }

  return system_config_form($form, $form_state);
}

/**
 * Form submission handler for snapengage_admin_settings_form().
 *
 * @see snapengage_admin_settings_form()
 * @ingroup forms
 */
function snapengage_admin_settings_form_submit($form, &$form_state) {
  config('snapengage.settings')
    ->set('widget_id', $form['account']['widget_id']['#value'])
    ->set('roles', $form['role_vis_settings']['roles']['#value'])
    ->set('visibility', (int) $form['page_vis_settings']['visibility']['#value'])
    ->set('pages', $form['page_vis_settings']['pages']['#value'])
    ->save();
}
